==> org.Gg.eg.db_2.3.5.tar.gz: org.Gg.eg.db/man/org.Gg.egPFAM.Rd <==
\name{org.Gg.egPFAM}
\alias{org.Gg.egPFAM}
\title{Map Entrez Gene IDs to Pfam IDs}
\description{
  org.Gg.egPFAM is an R object that provides mappings between an
  entrez gene identifier and the associated Pfam identifiers.
}
\details{
  Each entrez gene identifier maps to a named vector of Pfam identifiers.  The name
  for each Pfam identifier is the IPI accession numbe where this Pfam identifier is found.

  If the Pfam is a named NA, it means that the associated Entrez Gene id
  of this entrez gene identifier is found in an IPI entry of the IPI database,
  but there is no Pfam identifier in the entry.

  If the Pfam is a non-named NA, it means that the associated Entrez Gene id
  of this entrez gene identifier is not found in any IPI entry of the IPI database.

   Mappings were based on data provided by: The International Protein Index  
  ftp://ftp.ebi.ac.uk/pub/databases/IPI/current  
  With a date stamp from the source of: 2009-Jul29

}
\references{
  Kersey P. J., Duarte J., Williams A., Karavidopoulou Y., Birney E., Apweiler R.
  The International Protein Index: An integrated database for proteomics experiments.
  Proteomics 4(7): 1985-1988 (2004)
  \url{http://www.ebi.ac.uk/IPI/IPIhelp.html}
}
\examples{
        x <- org.Gg.egPFAM
        # Get the entrez gene identifiers that are mapped to any Pfam ID
        mapped_genes <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_genes])
        # randomly display 10 genes
        sample(xx, 10)
}
\keyword{datasets}

==> org.Gg.eg.db_2.4.1.tar.gz: org.Gg.eg.db/man/org.Gg.egPFAM.Rd <==
\name{org.Gg.egPFAM}
\alias{org.Gg.egPFAM}
\title{Map Entrez Gene IDs to Pfam IDs}
\description{
  org.Gg.egPFAM is an R object that provides mappings between an
  entrez gene identifier and the associated Pfam identifiers.
}
\details{
  Each entrez gene identifier maps to a named vector of Pfam identifiers.  The name
  for each Pfam identifier is the IPI accession numbe where this Pfam identifier is found.

  If the Pfam is a named NA, it means that the associated Entrez Gene id
  of this entrez gene identifier is found in an IPI entry of the IPI database,
  but there is no Pfam identifier in the entry.

  If the Pfam is a non-named NA, it means that the associated Entrez Gene id
  of this entrez gene identifier is not found in any IPI entry of the IPI database.

   Mappings were based on data provided by: The International Protein Index  
  ftp://ftp.ebi.ac.uk/pub/databases/IPI/current  
  With a date stamp from the source of: 2010-Feb10

}
\references{
  Kersey P. J., Duarte J., Williams A., Karavidopoulou Y., Birney E., Apweiler R.
  The International Protein Index: An integrated database for proteomics experiments.
  Proteomics 4(7): 1985-1988 (2004)
  \url{http://www.ebi.ac.uk/IPI/IPIhelp.html}
}
\examples{
        x <- org.Gg.egPFAM
        # Get the entrez gene identifiers that are mapped to any Pfam ID
        mapped_genes <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_genes])
        # randomly display 10 genes
        sample(xx, 10)
}
\keyword{datasets}
